Creates a grouping strategy that routes all observations of a group to the same child node. This is the default grouping strategy for classification.
Creates a grouping strategy that routes all observations of a group to the same child node. This is the default grouping strategy for classification.