Creates a stopping rule that stops splitting when a node contains only one group. This is the default stopping rule for classification.
Creates a stopping rule that stops splitting when a node contains only one group. This is the default stopping rule for classification.